@@ -13,10 +13,10 @@
 
 # You should have received a copy of the GNU Lesser General Public License along with PyGithub.  If not, see <http://www.gnu.org/licenses/>.
 
-import GithubObject
+import github.GithubObject
 
 
-class GitTreeElement(GithubObject.BasicGithubObject):
+class GitTreeElement(github.GithubObject.BasicGithubObject):
     @property
     def mode(self):
         return self._NoneIfNotSet(self._mode)
@@ -42,12 +42,12 @@ class GitTreeElement(GithubObject.BasicGithubObject):
         return self._NoneIfNotSet(self._url)
 
     def _initAttributes(self):
-        self._mode = GithubObject.NotSet
-        self._path = GithubObject.NotSet
-        self._sha = GithubObject.NotSet
-        self._size = GithubObject.NotSet
-        self._type = GithubObject.NotSet
-        self._url = GithubObject.NotSet
+        self._mode = github.GithubObject.NotSet
+        self._path = github.GithubObject.NotSet
+        self._sha = github.GithubObject.NotSet
+        self._size = github.GithubObject.NotSet
+        self._type = github.GithubObject.NotSet
+        self._url = github.GithubObject.NotSet
 
     def _useAttributes(self, attributes):
         if "mode" in attributes:  # pragma no branch
